@@ -7,14 +7,15 @@ package Comics::Plugin::PoorlyDrawnLines;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.02";
+our $VERSION = "1.04";
 
 our $name    = "Poorly Drawn Lines";
 our $url     = "http://www.poorlydrawnlines.com/";
 
 our $pattern =
-  qr{ <figure \s+ class="wp-block-image[^"]*"> \s*
-      <img \s+
+  qr{ <div \s+ class="wp-block-image[^"]*"> \s*
+      <figure \s+ class=".*?">
+      <img \s+ (?: (?:loading|width|height) = "[^"]+" \s+ )*
        src="(?<url>https?://www.poorlydrawnlines.com/wp-content/uploads/
 	      \d+/\d+/
 	      (?<image>.+?\.\w+))"
